==> py-iqoption-api-1.1.4.tar.gz: py-iqoption-api-1.1.4/pyiqoptionapi/ws/chanels/leaderboard.py <==
from .base import Base
import time


class LeaderBoard(Base):
    """
    {"name":"sendMessage","request_id":"356","msg":{"name":"request-leaderboard-deals-client","version":"1.0",
    "body":{"country_id":0,"user_country_id":191,"from_position":1,"to_position":64,"near_traders_country_count":64,
    "near_traders_count":64,"top_country_count":64,"top_count":64,"top_type":2}}}
    """

    name = "sendMessage"

    def __call__(self,
                 country_id,
                 user_country_id,
                 from_position,
                 to_position,
                 near_traders_country_count,
                 near_traders_count,
                 top_country_count,
                 top_count,
                 top_type):
        
        data = {"name": "request-leaderboard-deals-client",
                "version": "1.0",
                "body": {
                          "country_id": country_id,
                          "user_country_id": user_country_id,
                          "from_position": from_position,
                          "to_position": to_position,
                          "near_traders_country_count": near_traders_country_count,
                          "near_traders_count": near_traders_count,
                          "top_country_count": top_country_count,
                          "top_count": top_count,
                          "top_type": top_type
                        }
                }

        self.send_websocket_request(self.name, data)

==> py-iqoption-api-1.1.100.tar.gz: py-iqoption-api-1.1.100/pyiqoptionapi/ws/chanels/leaderboard.py <==
from pyiqoptionapi.ws.chanels.base import Base
import time


class Leader_Board(Base):
    """
    {"name":"sendMessage","request_id":"356","msg":{"name":"request-leaderboard-deals-client","version":"1.0","body":{"country_id":0,"user_country_id":191,"from_position":1,"to_position":64,"near_traders_country_count":64,"near_traders_count":64,"top_country_count":64,"top_count":64,"top_type":2}}}
    """

    name = "sendMessage"

    def __call__(self,
                 country_id,
                 user_country_id,
                 from_position,
                 to_position,
                 near_traders_country_count,
                 near_traders_count,
                 top_country_count,
                 top_count,
                 top_type):
        
        data = {"name": "request-leaderboard-deals-client",
                "version": "1.0",
                "body": {
                          "country_id": country_id,
                          "user_country_id": user_country_id,
                          "from_position": from_position,
                          "to_position": to_position,
                          "near_traders_country_count": near_traders_country_count,
                          "near_traders_count": near_traders_count,
                          "top_country_count": top_country_count,
                          "top_count": top_count,
                          "top_type": top_type
                        }
                }

        self.send_websocket_request(self.name, data)
